// ------------------------------------------------------------------------
// Simple J1939 Data Traffic Simulator
// ------------------------------------------------------------------------
//
// IMPOPRTANT: Depending on the CAN shield used for this programming sample,
//             please make sure you set the proper CS pin in module can.cpp.
//
//  This Arduino program is free software; you can redistribute it and/or
//  modify it under the terms of the GNU Lesser General Public
//  License as published by the Free Software Foundation; either
//  version 2.1 of the License, or (at your option) any later version.

//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.

#include <stdlib.h>
#include <SPI.h>

#include "mcp_can.h"
#include "can_ext.h"

// Simulation variables ---------------------------------------------------
// ------------------------------------------------------------------------
int nCounter = 0;

unsigned char msgVehiclePosition[8] = {0x31, 0x32, 0x33, 0x34, 0x35, 0x36, 0x37, 0x38}; 
unsigned char msgAmbientConditions[8] = {0x38, 0x37, 0x36, 0x35, 0x34, 0x33, 0x32, 0x31};

// ------------------------------------------------------------------------
//  SYSTEM: Setup routine runs on power-up or reset
// ------------------------------------------------------------------------
void setup()
{
  // Set the serial interface baud rate
  Serial.begin(115200);
  
    // Initialize the CAN controller
  if (canInitialize(CAN_250KBPS) == CAN_OK)  // Baud rates defined in mcp_can_dfs.h
    Serial.print("CAN Init OK.\n\r\n\r");
  else
    Serial.print("CAN Init Failed.\n\r");
  
}// end setup

// ------------------------------------------------------------------------
// Main Loop - Arduino Entry Point
// ------------------------------------------------------------------------
void loop() 
{
  // Establish the timer base
  delay(1000);    // 1 sec
  nCounter++;

  // Send out PGN 65629 - Ambient Conditions
  canTransmit(0x18FEF530, msgAmbientConditions, 8);

  // Send out PGN 65627 - Vehicle Position
  if(nCounter == 5)
  {
    canTransmit(0x18FEF320, msgVehiclePosition, 8);
    nCounter = 0;  // Reset the counter
    
  }// end if

}// end loop

